%global base_name httpcomponents

Name:              httpcomponents-client
Summary:           HTTP agent implementation based on httpcomponents HttpCore
Version:           4.3.5
Release:           %mkrel 1
Group:             Development/Java
License:           ASL 2.0
URL:               http://hc.apache.org/
Source0:           http://www.apache.org/dist/httpcomponents/httpclient/source/%{name}-%{version}-src.tar.gz
BuildArch:         noarch

BuildRequires:     maven-local
BuildRequires:     mvn(commons-codec:commons-codec)
BuildRequires:     mvn(commons-logging:commons-logging)
BuildRequires:     mvn(org.apache.httpcomponents:httpcore)
BuildRequires:     mvn(org.apache.httpcomponents:project:pom:)
BuildRequires:     mvn(org.codehaus.mojo:build-helper-maven-plugin)

%description
HttpClient is a HTTP/1.1 compliant HTTP agent implementation based on
httpcomponents HttpCore. It also provides reusable components for
client-side authentication, HTTP state management, and HTTP connection
management. HttpComponents Client is a successor of and replacement
for Commons HttpClient 3.x. Users of Commons HttpClient are strongly
encouraged to upgrade.

%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
%{summary}.


%prep
%setup -q

# Don't install javadoc, sources and tests jars
%mvn_package ":{*}::{tests,sources,javadoc}:" __noinstall

# Remove optional build deps not available in Fedora
%pom_disable_module httpclient-cache
%pom_disable_module httpclient-osgi
%pom_disable_module fluent-hc
%pom_remove_plugin :docbkx-maven-plugin
%pom_remove_plugin :clirr-maven-plugin
%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_dep :mockito-core httpclient

# Add proper Apache felix bundle plugin instructions
# so that we get a reasonable OSGi manifest.
for module in httpclient httpmime; do
    %pom_xpath_remove "pom:project/pom:packaging" $module
    %pom_xpath_inject "pom:project" "<packaging>bundle</packaging>" $module
done

# Make httpmime into bundle
%pom_xpath_inject pom:build/pom:plugins "
    <plugin>
      <groupId>org.apache.felix</groupId>
      <artifactId>maven-bundle-plugin</artifactId>
      <extensions>true</extensions>
    </plugin>" httpmime

# Make httpclient into bundle
%pom_xpath_inject pom:reporting/pom:plugins "
    <plugin>
      <groupId>org.apache.felix</groupId>
      <artifactId>maven-bundle-plugin</artifactId>
      <configuration>
        <instructions>
          <Export-Package>*</Export-Package>
          <Private-Package></Private-Package>
          <Import-Package>!org.apache.avalon.framework.logger,!org.apache.log,!org.apache.log4j,*</Import-Package>
        </instructions>
      </configuration>
    </plugin>" httpclient
%pom_xpath_inject pom:build/pom:plugins "
    <plugin>
      <groupId>org.apache.felix</groupId>
      <artifactId>maven-bundle-plugin</artifactId>
      <extensions>true</extensions>
      <configuration>
        <instructions>
          <Export-Package>org.apache.http.*,!org.apache.http.param</Export-Package>
          <Private-Package></Private-Package>
          <_nouses>true</_nouses>
          <Import-Package>!org.apache.avalon.framework.logger,!org.apache.log,!org.apache.log4j,*</Import-Package>
        </instructions>
        <excludeDependencies>true</excludeDependencies>
      </configuration>
    </plugin>" httpclient



%build
%mvn_file ":{*}" httpcomponents/@1

# tests are disabled due to bug in mockito (rhbz#1040350)
%mvn_build -f

%install
%mvn_install


%files -f .mfiles
%doc LICENSE.txt NOTICE.txt README.txt RELEASE_NOTES.txt

%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt NOTICE.txt




%changelog
* Wed Aug 20 2014 luigiwalser <luigiwalser> 4.3.5-1.mga4
+ Revision: 666044
- 4.3.5 (fixes CVE-2014-3577)
- fix BR on httpcomponents-project

* Sat Dec 21 2013 dmorgan <dmorgan> 4.3-1.mga4
+ Revision: 559540
- Build with maven-local
- New version
- Build with xmvn
- New version

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 4.2.2-2.mga3
+ Revision: 353347
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 04 2012 dmorgan <dmorgan> 4.2.2-1.mga3
+ Revision: 326393
- New version

* Wed Sep 12 2012 dmorgan <dmorgan> 4.2.1-1.mga3
+ Revision: 292977
- New version

* Sat Sep 08 2012 dmorgan <dmorgan> 4.1.3-3.mga3
+ Revision: 290514
- Do not export org.apache.http.param in osgi.

* Mon Jul 16 2012 dmorgan <dmorgan> 4.1.3-2.mga3
+ Revision: 271252
- Do not export * but only org.apache.http.* .
- Do not generate uses clauses in the manifest.

* Mon Jul 09 2012 dmorgan <dmorgan> 4.1.3-1.mga3
+ Revision: 269085
- New version 4.1.3

* Sat Dec 10 2011 dmorgan <dmorgan> 4.1.2-1.mga2
+ Revision: 179896
- New version 4.1.2
- Fix for RH Bz#718830. Add instructions so as to not
  Import-Package optional dependencies.

* Tue Jul 19 2011 dmorgan <dmorgan> 4.1.1-3.mga2
+ Revision: 126097
- Add BR/R apache-commons-codec, since httpcomponents-client's
  MANIFEST.MF has an Import-Package: org.apache.commons.codec
  header.

* Thu Apr 28 2011 dmorgan <dmorgan> 4.1.1-2.mga1
+ Revision: 92452
- Rebuild after bootstrapping
- imported package httpcomponents-client

